@@ -80,6 +80,15 @@ public interface NotificationsManager {
 	 * @return true if the notification is correctly delivered, false otherwise
 	 */
 	boolean notifyUpdatedItem(String userIdToNotify, WorkspaceItem item, WorkspaceFolder sharedFolder) throws Exception;
+	/**
+	 * use to notify a user he got a workspace item renamed
+	 *
+	 * @param userIdToNotify the user you want to notify
+	 * @param previousName the previous name of the folder
+	 * @param renamedItem the renamed {@link WorkspaceItem}  
+	 * @return true if the notification is correctly delivered, false otherwise
+	 */
+	boolean notifyItemRenaming(String userIdToNotify, String previousName, WorkspaceItem renamedItem) throws Exception;
 	/**
 	 * 
 	 * @param userIdToNotify the user you want to notify
